@@ -146,7 +146,10 @@ class ModelLookup(LookupBase):
         return qs
 
     def get_queryset(self):
-        qs = self.model._default_manager.get_query_set()
+        try:
+            qs = self.model._default_manager.get_queryset()
+        except AttributeError:  # Django <= 1.5.
+            qs = self.model._default_manager.get_query_set()
         if self.filters:
             qs = qs.filter(**self.filters)
         return qs
