@@ -2,9 +2,8 @@ from __future__ import unicode_literals
 
 from django import forms
 from django.conf import settings
-from django.utils.importlib import import_module
 
-from selectable.compat import string_types
+from selectable.compat import string_types, import_module
 
 
 __all__ = (
