@@ -4,6 +4,7 @@ from django import forms
 from django.core.exceptions import ValidationError
 from django.core.validators import EMPTY_VALUES
 from django.utils.translation import ugettext_lazy as _
+from django.db.models import Model
 
 from selectable.forms.base import import_lookup_class
 from selectable.forms.widgets import AutoCompleteSelectWidget
@@ -15,7 +16,32 @@ __all__ = (
 )
 
 
-class AutoCompleteSelectField(forms.Field):
+def model_vars(obj):
+    fields = dict(
+        (field.name, getattr(obj, field.name))
+        for field in obj._meta.fields
+    )
+    return fields
+
+
+class BaseAutoCompleteField(forms.Field):
+
+    def _has_changed(self, initial, data):
+        "Detects if the data was changed. This is added in 1.6."
+        if initial is None and data is None:
+            return False
+        if data and not hasattr(data, '__iter__'):
+            data = self.widget.decompress(data)
+        initial = self.to_python(initial)
+        data = self.to_python(data)
+        if hasattr(self, '_coerce'):
+            data = self._coerce(data)
+        if isinstance(data, Model) and isinstance(initial, Model):
+            return model_vars(data) != model_vars(initial)
+        else:
+            return data != initial
+
+class AutoCompleteSelectField(BaseAutoCompleteField):
     widget = AutoCompleteSelectWidget
 
     default_error_messages = {
@@ -31,14 +57,7 @@ class AutoCompleteSelectField(forms.Field):
             kwargs['widget'] = widget(lookup_class, allow_new=self.allow_new, limit=self.limit)
         super(AutoCompleteSelectField, self).__init__(*args, **kwargs)
 
-    def _has_changed(self, initial, data):
-        "Detects if the data was changed. This is added in 1.6."
-        if initial is None and data is None:
-            return False
-        if data and not hasattr(data, '__iter__'):
-            data = self.widget.decompress(data)
-        initial = self.to_python(initial)
-        return super(AutoCompleteSelectField, self)._has_changed(initial, data)
+
 
     def to_python(self, value):
         if value in EMPTY_VALUES:
@@ -70,7 +89,7 @@ class AutoCompleteSelectField(forms.Field):
         return value
 
 
-class AutoCompleteSelectMultipleField(forms.Field):
+class AutoCompleteSelectMultipleField(BaseAutoCompleteField):
     widget = AutoCompleteSelectMultipleWidget
 
     default_error_messages = {
@@ -85,15 +104,6 @@ class AutoCompleteSelectMultipleField(forms.Field):
             kwargs['widget'] = widget(lookup_class, limit=self.limit)
         super(AutoCompleteSelectMultipleField, self).__init__(*args, **kwargs)
 
-    def _has_changed(self, initial, data):
-        "Detects if the data was changed. This is added in 1.6."
-        if initial is None and data is None:
-            return False
-        if data and not hasattr(data, '__iter__'):
-            data = self.widget.decompress(data)
-        initial = self.to_python(initial)
-        return super(AutoCompleteSelectMultipleField, self)._has_changed(initial, data)
-
     def to_python(self, value):
         if value in EMPTY_VALUES:
             return []
