@@ -1,14 +1,14 @@
 /*jshint trailing:true, indent:4*/
 /*
  * django-selectable UI widget
- * Source: https://bitbucket.org/mlavin/django-selectable
+ * Source: https://github.com/mlavin/django-selectable
  * Docs: http://django-selectable.readthedocs.org/
  *
  * Depends:
- *   - jQuery 1.4.4+
+ *   - jQuery 1.7+
  *   - jQuery UI 1.8 widget factory
  *
- * Copyright 2010-2013, Mark Lavin
+ * Copyright 2010-2014, Mark Lavin
  * BSD License
  *
 */
@@ -313,7 +313,7 @@
         },
         close: function (event) {
             var page = $(this.element).data('page');
-            if (page != null) {
+            if (page !== null) {
                 return;
             }
             // Call super trigger
@@ -334,7 +334,7 @@
     function djangoAdminPatches() {
         /* Listen for new rows being added to the dynamic inlines.
         Requires Django 1.5+ */
-        $('.add-row').click(function (e) {
+        $('body').on('click', '.add-row', function (e) {
             var wrapper = $(this).parents('.inline-related'),
                 newRow = $('.form-row:not(.empty-form)', wrapper).last();
             window.bindSelectables(newRow);
